Include files.

Home Download News Documentation FAQ Tutorial API reference Examples XML Digital Signature Online Verifier XML Encryption XML Canonicalization Reporting Bugs Mailing list Related Authors
# Include files. In order to use XML Security Library an application should include one or more of the following files: xmlsec/xmlsec.h - XML Security Library initialization and shutdown functions; xmlsec/xmldsig.h - XML Digital Signature functions; xmlsec/xmlenc.h - XML Encryption functions; xmlsec/xmltree.h - helper functions for XML documents manipulation; xmlsec/templates.h - helper functions for dynamic XML Digital Signature and XML Encryption templates creation; xmlsec/crypto.h - automatic XML Security Crypto Library selection. If necessary, the application should also include LibXML, LibXSLT and crypto library header files. Example 1. Example includes file section.
    #include <libxml/tree.h>
    #include <libxml/xmlmemory.h>
    #include <libxml/parser.h>

    #ifndef XMLSEC_NO_XSLT
    #include <libxslt/xslt.h>
    #endif /* XMLSEC_NO_XSLT */

    #include <xmlsec/xmlsec.h>
    #include <xmlsec/xmltree.h>
    #include <xmlsec/xmldsig.h>
    #include <xmlsec/xmlenc.h>
    #include <xmlsec/templates.h>
    #include <xmlsec/crypto.h>